@@ -17,6 +17,8 @@ import {
     type SyncStateData,
     SyncState,
     EventType,
+    ProfileKeyTimezone,
+    ProfileKeyMSC4175Timezone,
 } from "matrix-js-sdk/src/matrix";
 import { type MatrixCall } from "matrix-js-sdk/src/webrtc/call";
 import classNames from "classnames";
@@ -30,7 +32,6 @@ import SettingsStore from "../../settings/SettingsStore";
 import { SettingLevel } from "../../settings/SettingLevel";
 import ResizeHandle from "../views/elements/ResizeHandle";
 import { CollapseDistributor, Resizer } from "../../resizer";
-import type ResizeNotifier from "../../utils/ResizeNotifier";
 import PlatformPeg from "../../PlatformPeg";
 import { DefaultTagID } from "../../stores/room-list/models";
 import { hideToast as hideServerLimitToast, showToast as showServerLimitToast } from "../../toasts/ServerLimitToast";
@@ -67,6 +68,8 @@ import { monitorSyncedPushRules } from "../../utils/pushRules/monitorSyncedPushR
 import { type ConfigOptions } from "../../SdkConfig";
 import { MatrixClientContextProvider } from "./MatrixClientContextProvider";
 import { Landmark, LandmarkNavigation } from "../../accessibility/LandmarkNavigation";
+import { ModuleApi } from "../../modules/Api.ts";
+import { SDKContext } from "../../contexts/SDKContext.ts";
 
 // We need to fetch each pinned message individually (if we don't already have it)
 // so each pinned message may trigger a request. Limit the number per room for sanity.
@@ -86,7 +89,6 @@ interface IProps {
     // transitioned to PWLU)
     onRegistered: (credentials: IMatrixClientCreds) => Promise<MatrixClient>;
     hideToSRUsers: boolean;
-    resizeNotifier: ResizeNotifier;
     // eslint-disable-next-line camelcase
     page_type?: string;
     autoJoin?: boolean;
@@ -134,8 +136,11 @@ class LoggedInView extends React.Component<IProps, IState> {
     protected timezoneProfileUpdateRef?: string[];
     protected resizer?: Resizer<ICollapseConfig, CollapseItem>;
 
-    public constructor(props: IProps) {
-        super(props);
+    public static contextType = SDKContext;
+    declare public context: React.ContextType<typeof SDKContext>;
+
+    public constructor(props: IProps, context: React.ContextType<typeof SDKContext>) {
+        super(props, context);
 
         this.state = {
             syncErrorData: undefined,
@@ -186,19 +191,37 @@ class LoggedInView extends React.Component<IProps, IState> {
             SettingsStore.watchSetting("userTimezone", null, this.onTimezoneUpdate),
         ];
 
-        this.resizer = this.createResizer();
-        this.resizer.attach();
+        this.loadResizer();
 
         OwnProfileStore.instance.on(UPDATE_EVENT, this.refreshBackgroundImage);
-        this.loadResizerPreferences();
         this.refreshBackgroundImage();
     }
 
+    /**
+     * Load or reload the resizer for the left panel
+     */
+    private loadResizer(): void {
+        // If the resizer already exists, detach it first
+        this.resizer?.detach();
+
+        this.resizer = this.createResizer();
+        this.resizer.attach();
+        this.loadResizerPreferences();
+    }
+
+    public componentDidUpdate(nextProps: Readonly<IProps>, nextState: Readonly<IState>, nextContext: any): void {
+        if (nextProps.page_type !== this.props.page_type) {
+            this.loadResizer();
+        }
+    }
+
     private onTimezoneUpdate = async (): Promise<void> => {
+        // TODO: In a future app release, remove support for legacy key.
         if (!SettingsStore.getValue("userTimezonePublish")) {
             // Ensure it's deleted
             try {
-                await this._matrixClient.deleteExtendedProfileProperty("us.cloke.msc4175.tz");
+                await this._matrixClient.deleteExtendedProfileProperty(ProfileKeyMSC4175Timezone);
+                await this._matrixClient.deleteExtendedProfileProperty(ProfileKeyTimezone);
             } catch (ex) {
                 console.warn("Failed to delete timezone from user profile", ex);
             }
@@ -213,7 +236,8 @@ class LoggedInView extends React.Component<IProps, IState> {
             return;
         }
         try {
-            await this._matrixClient.setExtendedProfileProperty("us.cloke.msc4175.tz", currentTimezone);
+            await this._matrixClient.setExtendedProfileProperty(ProfileKeyTimezone, currentTimezone);
+            await this._matrixClient.setExtendedProfileProperty(ProfileKeyMSC4175Timezone, currentTimezone);
         } catch (ex) {
             console.warn("Failed to update user profile with current timezone", ex);
         }
@@ -281,15 +305,15 @@ class LoggedInView extends React.Component<IProps, IState> {
             },
             onResized: (size) => {
                 panelSize = size;
-                this.props.resizeNotifier.notifyLeftHandleResized();
+                this.context.resizeNotifier.notifyLeftHandleResized();
             },
             onResizeStart: () => {
-                this.props.resizeNotifier.startResizing();
+                this.context.resizeNotifier.startResizing();
             },
             onResizeStop: () => {
                 // Always save the lhs size for the new room list.
                 if (useNewRoomList || !panelCollapsed) window.localStorage.setItem("mx_lhs_size", "" + panelSize);
-                this.props.resizeNotifier.stopResizing();
+                this.context.resizeNotifier.stopResizing();
             },
             isItemCollapsed: (domNode) => {
                 // New rooms list does not support collapsing.
@@ -672,6 +696,10 @@ class LoggedInView extends React.Component<IProps, IState> {
     public render(): React.ReactNode {
         let pageElement;
 
+        const moduleRenderer = this.props.page_type
+            ? ModuleApi.instance.navigation.locationRenderers.get(this.props.page_type)
+            : undefined;
+
         switch (this.props.page_type) {
             case PageTypes.RoomView:
                 pageElement = (
@@ -681,7 +709,6 @@ class LoggedInView extends React.Component<IProps, IState> {
                         threepidInvite={this.props.threepidInvite}
                         oobData={this.props.roomOobData}
                         key={this.props.currentRoomId || "roomview"}
-                        resizeNotifier={this.props.resizeNotifier}
                         justCreatedOpts={this.props.roomJustCreatedOpts}
                         forceTimeline={this.props.forceTimeline}
                     />
@@ -695,10 +722,17 @@ class LoggedInView extends React.Component<IProps, IState> {
             case PageTypes.UserView:
                 if (!!this.props.currentUserId) {
                     pageElement = (
-                        <UserView userId={this.props.currentUserId} resizeNotifier={this.props.resizeNotifier} />
+                        <UserView userId={this.props.currentUserId} resizeNotifier={this.context.resizeNotifier} />
                     );
                 }
                 break;
+            default: {
+                if (moduleRenderer) {
+                    pageElement = moduleRenderer();
+                } else {
+                    console.warn(`Couldn't render page type "${this.props.page_type}"`);
+                }
+            }
         }
 
         const wrapperClasses = classNames({
@@ -740,20 +774,22 @@ class LoggedInView extends React.Component<IProps, IState> {
                                 )}
                                 <SpacePanel />
                                 {!useNewRoomList && <BackdropPanel backgroundImage={this.state.backgroundImage} />}
-                                <div
-                                    className="mx_LeftPanel_wrapper--user"
-                                    ref={this._resizeContainer}
-                                    data-collapsed={shouldUseMinimizedUI ? true : undefined}
-                                >
-                                    <LeftPanel
-                                        pageType={this.props.page_type as PageTypes}
-                                        isMinimized={shouldUseMinimizedUI || false}
-                                        resizeNotifier={this.props.resizeNotifier}
-                                    />
-                                </div>
+                                {!moduleRenderer && (
+                                    <div
+                                        className="mx_LeftPanel_wrapper--user"
+                                        ref={this._resizeContainer}
+                                        data-collapsed={shouldUseMinimizedUI ? true : undefined}
+                                    >
+                                        <LeftPanel
+                                            pageType={this.props.page_type as PageTypes}
+                                            isMinimized={shouldUseMinimizedUI || false}
+                                            resizeNotifier={this.context.resizeNotifier}
+                                        />
+                                    </div>
+                                )}
                             </div>
                         </div>
-                        <ResizeHandle passRef={this.resizeHandler} id="lp-resizer" />
+                        {!moduleRenderer && <ResizeHandle passRef={this.resizeHandler} id="lp-resizer" />}
                         <div className="mx_RoomView_wrapper">{pageElement}</div>
                     </div>
                 </div>
