@@ -32,7 +32,6 @@ import {
     RoomType,
     GuestAccess,
     HistoryVisibility,
-    type HierarchyRelation,
     type HierarchyRoom,
     JoinRule,
 } from "matrix-js-sdk/src/matrix";
@@ -68,9 +67,11 @@ import { type JoinRoomReadyPayload } from "../../dispatcher/payloads/JoinRoomRea
 import { KeyBindingAction } from "../../accessibility/KeyboardShortcuts";
 import { getKeyBindingsManager } from "../../KeyBindingsManager";
 import { getTopic } from "../../hooks/room/useTopic";
-import { SdkContextClass } from "../../contexts/SDKContext";
 import { getDisplayAliasForAliasSet } from "../../Rooms";
 import SettingsStore from "../../settings/SettingsStore";
+import { filterBoolean } from "../../utils/arrays.ts";
+import { type RoomViewStore } from "../../stores/RoomViewStore.tsx";
+import RoomContext from "../../contexts/RoomContext.ts";
 
 interface IProps {
     space: Room;
@@ -404,7 +405,20 @@ export const showRoom = (cli: MatrixClient, hierarchy: RoomHierarchy, roomId: st
     });
 };
 
-export const joinRoom = async (cli: MatrixClient, hierarchy: RoomHierarchy, roomId: string): Promise<unknown> => {
+/**
+ * Join a room.
+ * @param cli The Matrix client
+ * @param roomViewStore The RoomViewStore instance
+ * @param hierarchy The RoomHierarchy instance
+ * @param roomId The ID of the room to join
+ * @returns A promise that resolves when the room has been joined
+ */
+export const joinRoom = async (
+    cli: MatrixClient,
+    roomViewStore: RoomViewStore,
+    hierarchy: RoomHierarchy,
+    roomId: string,
+): Promise<unknown> => {
     // Don't let the user view a room they won't be able to either peek or join:
     // fail earlier so they don't have to click back to the directory.
     if (cli.isGuest()) {
@@ -418,10 +432,10 @@ export const joinRoom = async (cli: MatrixClient, hierarchy: RoomHierarchy, room
         });
     } catch (err: unknown) {
         if (err instanceof MatrixError) {
-            SdkContextClass.instance.roomViewStore.showJoinRoomError(err, roomId);
+            roomViewStore.showJoinRoomError(err, roomId);
         } else {
             logger.warn("Got a non-MatrixError while joining room", err);
-            SdkContextClass.instance.roomViewStore.showJoinRoomError(
+            roomViewStore.showJoinRoomError(
                 new MatrixError({
                     error: _t("error|unknown"),
                 }),
@@ -504,68 +518,67 @@ export const HierarchyLevel: React.FC<IHierarchyLevelProps> = ({
     const space = cli.getRoom(root.room_id);
     const hasPermissions = space?.currentState.maySendStateEvent(EventType.SpaceChild, cli.getSafeUserId());
 
-    const sortedChildren = sortBy(root.children_state, (ev) => {
-        return getChildOrder(ev.content.order, ev.origin_server_ts, ev.state_key);
-    });
-
-    const [subspaces, childRooms] = sortedChildren.reduce(
-        (result, ev: HierarchyRelation) => {
-            const room = hierarchy.roomMap.get(ev.state_key);
-            if (room && roomSet.has(room)) {
-                result[room.room_type === RoomType.Space ? 0 : 1].push(toLocalRoom(cli, room, hierarchy));
-            }
-            return result;
-        },
-        [[] as HierarchyRoom[], [] as HierarchyRoom[]],
+    const sortedChildren = filterBoolean(
+        sortBy(root.children_state, (ev) => {
+            return getChildOrder(ev.content.order, ev.origin_server_ts, ev.state_key);
+        }).map((ev) => {
+            const hierarchyRoom = hierarchy.roomMap.get(ev.state_key);
+            if (!hierarchyRoom || !roomSet.has(hierarchyRoom)) return null;
+            // Find the most up-to-date info for this room, if it has been upgraded and we know about it.
+            return toLocalRoom(cli, hierarchyRoom, hierarchy);
+        }),
     );
 
     const newParents = new Set(parents).add(root.room_id);
     return (
         <React.Fragment>
-            {uniqBy(childRooms, "room_id").map((room) => (
-                <Tile
-                    key={room.room_id}
-                    room={room}
-                    suggested={hierarchy.isSuggested(root.room_id, room.room_id)}
-                    selected={selectedMap?.get(root.room_id)?.has(room.room_id)}
-                    onViewRoomClick={() => onViewRoomClick(room.room_id, room.room_type as RoomType)}
-                    onJoinRoomClick={() => onJoinRoomClick(room.room_id, newParents)}
-                    hasPermissions={hasPermissions}
-                    onToggleClick={onToggleClick ? () => onToggleClick(root.room_id, room.room_id) : undefined}
-                />
-            ))}
-
-            {subspaces
-                .filter((room) => !newParents.has(room.room_id))
-                .map((space) => (
-                    <Tile
-                        key={space.room_id}
-                        room={space}
-                        numChildRooms={
-                            space.children_state.filter((ev) => {
-                                const room = hierarchy.roomMap.get(ev.state_key);
-                                return room && roomSet.has(room) && !room.room_type;
-                            }).length
-                        }
-                        suggested={hierarchy.isSuggested(root.room_id, space.room_id)}
-                        selected={selectedMap?.get(root.room_id)?.has(space.room_id)}
-                        onViewRoomClick={() => onViewRoomClick(space.room_id, RoomType.Space)}
-                        onJoinRoomClick={() => onJoinRoomClick(space.room_id, newParents)}
-                        hasPermissions={hasPermissions}
-                        onToggleClick={onToggleClick ? () => onToggleClick(root.room_id, space.room_id) : undefined}
-                    >
-                        <HierarchyLevel
-                            root={space}
-                            roomSet={roomSet}
-                            hierarchy={hierarchy}
-                            parents={newParents}
-                            selectedMap={selectedMap}
-                            onViewRoomClick={onViewRoomClick}
-                            onJoinRoomClick={onJoinRoomClick}
-                            onToggleClick={onToggleClick}
+            {uniqBy(sortedChildren, "room_id").map((room) => {
+                if (room.room_type !== RoomType.Space) {
+                    return (
+                        <Tile
+                            key={room.room_id}
+                            room={room}
+                            suggested={hierarchy.isSuggested(root.room_id, room.room_id)}
+                            selected={selectedMap?.get(root.room_id)?.has(room.room_id)}
+                            onViewRoomClick={() => onViewRoomClick(room.room_id, room.room_type as RoomType)}
+                            onJoinRoomClick={() => onJoinRoomClick(room.room_id, newParents)}
+                            hasPermissions={hasPermissions}
+                            onToggleClick={onToggleClick ? () => onToggleClick(root.room_id, room.room_id) : undefined}
                         />
-                    </Tile>
-                ))}
+                    );
+                } else {
+                    if (newParents.has(room.room_id)) return null; // prevent cycles
+                    return (
+                        <Tile
+                            key={room.room_id}
+                            room={room}
+                            numChildRooms={
+                                room.children_state.filter((ev) => {
+                                    const child = hierarchy.roomMap.get(ev.state_key);
+                                    return child && roomSet.has(child) && !child.room_type;
+                                }).length
+                            }
+                            suggested={hierarchy.isSuggested(root.room_id, room.room_id)}
+                            selected={selectedMap?.get(root.room_id)?.has(room.room_id)}
+                            onViewRoomClick={() => onViewRoomClick(room.room_id, RoomType.Space)}
+                            onJoinRoomClick={() => onJoinRoomClick(room.room_id, newParents)}
+                            hasPermissions={hasPermissions}
+                            onToggleClick={onToggleClick ? () => onToggleClick(root.room_id, room.room_id) : undefined}
+                        >
+                            <HierarchyLevel
+                                root={room}
+                                roomSet={roomSet}
+                                hierarchy={hierarchy}
+                                parents={newParents}
+                                selectedMap={selectedMap}
+                                onViewRoomClick={onViewRoomClick}
+                                onJoinRoomClick={onJoinRoomClick}
+                                onToggleClick={onToggleClick}
+                            />
+                        </Tile>
+                    );
+                }
+            })}
         </React.Fragment>
     );
 };
@@ -762,6 +775,7 @@ const ManageButtons: React.FC<IManageButtonsProps> = ({ hierarchy, selected, set
 
 const SpaceHierarchy: React.FC<IProps> = ({ space, initialText = "", showRoom, additionalButtons }) => {
     const cli = useContext(MatrixClientContext);
+    const roomContext = useContext(RoomContext);
     const [query, setQuery] = useState(initialText);
 
     const [selected, setSelected] = useState(new Map<string, Set<string>>()); // Map<parentId, Set<childId>>
@@ -856,10 +870,10 @@ const SpaceHierarchy: React.FC<IProps> = ({ space, initialText = "", showRoom, a
                                     onJoinRoomClick={async (roomId, parents) => {
                                         for (const parent of parents) {
                                             if (cli.getRoom(parent)?.getMyMembership() !== KnownMembership.Join) {
-                                                await joinRoom(cli, hierarchy, parent);
+                                                await joinRoom(cli, roomContext.roomViewStore, hierarchy, parent);
                                             }
                                         }
-                                        await joinRoom(cli, hierarchy, roomId);
+                                        await joinRoom(cli, roomContext.roomViewStore, hierarchy, roomId);
                                     }}
                                 />
                             </>
