@@ -244,7 +244,10 @@ export default class BasicMessageEditor extends React.Component<IProps, IState>
         if (isTyping && this.props.model.parts[0].type === "command") {
             const { cmd } = parseCommandString(this.props.model.parts[0].text);
             const command = CommandMap.get(cmd!);
-            if (!command?.isEnabled(MatrixClientPeg.get()) || command.category !== CommandCategories.messages) {
+            if (
+                !command?.isEnabled(MatrixClientPeg.get(), this.props.room.roomId) ||
+                command.category !== CommandCategories.messages
+            ) {
                 isTyping = false;
             }
         }
