@@ -9,10 +9,4 @@ export { ambiguousLinkTooltipRenderer } from "./link-tooltip";
 export { keywordPillRenderer, mentionPillRenderer } from "./pill";
 export { spoilerRenderer } from "./spoiler";
 export { codeBlockRenderer } from "./code-block";
-export {
-    applyReplacerOnString,
-    replacerToRenderFunction,
-    combineRenderers,
-    type RendererMap,
-    type Replacer,
-} from "./utils";
+export { applyReplacerOnString, combineRenderers, type RendererMap, type Replacer } from "./utils";
