@@ -52,6 +52,7 @@ import { ModuleRunner } from "../modules/ModuleRunner";
 import { setMarkedUnreadState } from "../utils/notifications";
 import { ConnectionState, ElementCall } from "../models/Call";
 import { isVideoRoom } from "../utils/video-rooms";
+import { ModuleApi } from "../modules/Api";
 
 const NUM_JOIN_RETRY = 5;
 
@@ -153,6 +154,7 @@ export class RoomViewStore extends EventEmitter {
     public constructor(
         dis: MatrixDispatcher,
         private readonly stores: SdkContextClass,
+        private readonly lockedToRoomId?: string,
     ) {
         super();
         this.resetDispatcher(dis);
@@ -187,7 +189,7 @@ export class RoomViewStore extends EventEmitter {
 
         const lastRoomId = this.state.roomId;
         this.state = Object.assign(this.state, newState);
-        if (lastRoomId !== this.state.roomId) {
+        if (!this.lockedToRoomId && lastRoomId !== this.state.roomId) {
             if (lastRoomId) this.emitForRoom(lastRoomId, false);
             if (this.state.roomId) this.emitForRoom(this.state.roomId, true);
 
@@ -204,6 +206,9 @@ export class RoomViewStore extends EventEmitter {
     }
 
     private onDispatch(payload: ActionPayload): void {
+        if (this.lockedToRoomId && payload.room_id && this.lockedToRoomId !== payload.room_id) {
+            return;
+        }
         // eslint-disable-line @typescript-eslint/naming-convention
         switch (payload.action) {
             // view_room:
@@ -281,17 +286,22 @@ export class RoomViewStore extends EventEmitter {
 
                 break;
             }
-            case "on_client_not_viable":
+            case Action.ClientNotViable:
             case Action.OnLoggedOut:
                 this.reset();
                 break;
             case "reply_to_event":
                 // Thread timeline view handles its own reply-to-state
                 if (TimelineRenderingType.Thread !== payload.context) {
+                    const roomId: string | undefined = payload.event?.getRoomId();
+
                     // If currently viewed room does not match the room in which we wish to reply then change rooms this
                     // can happen when performing a search across all rooms. Persist the data from this event for both
                     // room and search timeline rendering types, search will get auto-closed by RoomView at this time.
-                    if (payload.event && payload.event.getRoomId() !== this.state.roomId) {
+                    if (payload.event && roomId !== this.state.roomId) {
+                        // if the room is displayed in a module, we don't want to change the room view
+                        if (roomId && this.isRoomDisplayedInModule(roomId)) return;
+
                         this.dis?.dispatch<ViewRoomPayload>({
                             action: Action.ViewRoom,
                             room_id: payload.event.getRoomId(),
@@ -324,7 +334,7 @@ export class RoomViewStore extends EventEmitter {
         }
     }
 
-    private async viewRoom(payload: ViewRoomPayload): Promise<void> {
+    public async viewRoom(payload: ViewRoomPayload): Promise<void> {
         if (payload.room_id) {
             const room = MatrixClientPeg.safeGet().getRoom(payload.room_id);
 
@@ -361,7 +371,9 @@ export class RoomViewStore extends EventEmitter {
                 call.presented = true;
                 // Immediately start the call. This will connect to all required widget events
                 // and allow the widget to show the lobby.
-                if (call.connectionState === ConnectionState.Disconnected) call.start({ skipLobby: payload.skipLobby });
+                if (call.connectionState === ConnectionState.Disconnected) {
+                    call.start({ skipLobby: payload.skipLobby, voiceOnly: payload.voiceOnly });
+                }
             }
             // If we switch to a different room from the call, we are no longer presenting it
             const prevRoomCall = this.state.roomId ? CallStore.instance.getCall(this.state.roomId) : null;
@@ -796,4 +808,16 @@ export class RoomViewStore extends EventEmitter {
         ModuleRunner.instance.invoke(RoomViewLifecycle.ViewRoom, viewRoomOpts, this.getRoomId());
         this.setState({ viewRoomOpts });
     }
+
+    /**
+     * Checks if a room is already displayed in the current active space module.
+     * @param roomId
+     */
+    public isRoomDisplayedInModule(roomId: string): boolean {
+        const currentSpace = this.stores.spaceStore.activeSpace;
+        const cb = ModuleApi.instance.extras.visibleRoomBySpaceKey.get(currentSpace);
+        if (!cb) return false;
+
+        return cb().includes(roomId);
+    }
 }
