@@ -15,11 +15,11 @@ import { render } from "jest-matrix-react";
 
 import MessagePanel, { shouldFormContinuation } from "../../../../src/components/structures/MessagePanel";
 import SettingsStore from "../../../../src/settings/SettingsStore";
-import MatrixClientContext from "../../../../src/contexts/MatrixClientContext";
-import RoomContext, { TimelineRenderingType } from "../../../../src/contexts/RoomContext";
+import RoomContext, { type RoomContextType, TimelineRenderingType } from "../../../../src/contexts/RoomContext";
 import DMRoomMap from "../../../../src/utils/DMRoomMap";
 import * as TestUtilsMatrix from "../../../test-utils";
 import {
+    clientAndSDKContextRenderOptions,
     createTestClient,
     getMockClientWithEventEmitter,
     makeBeaconInfoEvent,
@@ -29,9 +29,9 @@ import {
     mockClientPushProcessor,
 } from "../../../test-utils";
 import type ResizeNotifier from "../../../../src/utils/ResizeNotifier";
-import { type IRoomState } from "../../../../src/components/structures/RoomView";
 import { MatrixClientPeg } from "../../../../src/MatrixClientPeg";
 import { ScopedRoomContextProvider } from "../../../../src/contexts/ScopedRoomContext.tsx";
+import { SdkContextClass } from "../../../../src/contexts/SDKContext.ts";
 
 jest.mock("../../../../src/utils/beacon", () => ({
     useBeacon: jest.fn(),
@@ -54,6 +54,7 @@ describe("MessagePanel", function () {
         getClientWellKnown: jest.fn().mockReturnValue({}),
         supportsThreads: jest.fn().mockReturnValue(true),
     });
+    let sdkContext: SdkContextClass;
     jest.spyOn(MatrixClientPeg, "get").mockReturnValue(client);
 
     const room = new Room(roomId, client, userId);
@@ -90,14 +91,12 @@ describe("MessagePanel", function () {
         showAvatarChanges: false,
         showDisplaynameChanges: true,
         showHiddenEvents: false,
-    } as unknown as IRoomState;
+    } as unknown as RoomContextType;
 
-    const getComponent = (props = {}, roomContext: Partial<IRoomState> = {}) => (
-        <MatrixClientContext.Provider value={client}>
-            <ScopedRoomContextProvider {...defaultRoomContext} {...roomContext}>
-                <MessagePanel {...defaultProps} {...props} />
-            </ScopedRoomContextProvider>
-        </MatrixClientContext.Provider>
+    const getComponent = (props = {}, roomContext: Partial<RoomContextType> = {}) => (
+        <ScopedRoomContextProvider {...defaultRoomContext} {...roomContext}>
+            <MessagePanel {...defaultProps} {...props} />
+        </ScopedRoomContextProvider>
     );
 
     beforeEach(function () {
@@ -107,6 +106,8 @@ describe("MessagePanel", function () {
             return arg === "showDisplaynameChanges";
         });
 
+        sdkContext = new SdkContextClass();
+
         DMRoomMap.makeShared(client);
     });
 
@@ -314,7 +315,7 @@ describe("MessagePanel", function () {
     }
 
     it("should show the events", function () {
-        const { container } = render(getComponent({ events }));
+        const { container } = render(getComponent({ events }), clientAndSDKContextRenderOptions(client, sdkContext));
 
         // just check we have the right number of tiles for now
         const tiles = container.getElementsByClassName("mx_EventTile");
@@ -322,7 +323,10 @@ describe("MessagePanel", function () {
     });
 
     it("should collapse adjacent member events", function () {
-        const { container } = render(getComponent({ events: mkMelsEvents() }));
+        const { container } = render(
+            getComponent({ events: mkMelsEvents() }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
 
         // just check we have the right number of tiles for now
         const tiles = container.getElementsByClassName("mx_EventTile");
@@ -339,6 +343,7 @@ describe("MessagePanel", function () {
                 readMarkerEventId: events[4].getId(),
                 readMarkerVisible: true,
             }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
         );
 
         const tiles = container.getElementsByClassName("mx_EventTile");
@@ -359,6 +364,7 @@ describe("MessagePanel", function () {
                 readMarkerEventId: melsEvents[4].getId(),
                 readMarkerVisible: true,
             }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
         );
 
         const [summary] = container.getElementsByClassName("mx_GenericEventListSummary");
@@ -381,6 +387,7 @@ describe("MessagePanel", function () {
                 readMarkerEventId: melsEvents[9].getId(),
                 readMarkerVisible: true,
             }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
         );
 
         const [summary] = container.getElementsByClassName("mx_GenericEventListSummary");
@@ -406,6 +413,7 @@ describe("MessagePanel", function () {
                     readMarkerVisible: true,
                 })}
             </div>,
+            clientAndSDKContextRenderOptions(client, sdkContext),
         );
 
         const tiles = container.getElementsByClassName("mx_EventTile");
@@ -448,7 +456,7 @@ describe("MessagePanel", function () {
         client.getRoom.mockImplementation((id) => (id === createEvent!.getRoomId() ? room : null));
         TestUtilsMatrix.upsertRoomStateEvents(room, events);
 
-        const { container } = render(getComponent({ events }));
+        const { container } = render(getComponent({ events }), clientAndSDKContextRenderOptions(client, sdkContext));
 
         // we expect that
         // - the room creation event, the room encryption event, and Alice inviting Bob,
@@ -476,7 +484,10 @@ describe("MessagePanel", function () {
         });
         const combinedEvents = [...events, beaconInfoEvent];
         TestUtilsMatrix.upsertRoomStateEvents(room, combinedEvents);
-        const { container } = render(getComponent({ events: combinedEvents }));
+        const { container } = render(
+            getComponent({ events: combinedEvents }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
 
         const [summaryTile] = container.getElementsByClassName("mx_GenericEventListSummary");
 
@@ -498,6 +509,7 @@ describe("MessagePanel", function () {
                 readMarkerEventId: events[5].getId(),
                 readMarkerVisible: true,
             }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
         );
 
         // find the <li> which wraps the read marker
@@ -514,7 +526,10 @@ describe("MessagePanel", function () {
 
     it("should render Date separators for the events", function () {
         const events = mkOneDayEvents();
-        const { queryAllByRole } = render(getComponent({ events }));
+        const { queryAllByRole } = render(
+            getComponent({ events }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         const dates = queryAllByRole("separator");
 
         expect(dates.length).toEqual(1);
@@ -523,7 +538,10 @@ describe("MessagePanel", function () {
     it("appends events into summaries during forward pagination without changing key", () => {
         const events = mkMelsEvents().slice(1, 11);
 
-        const { container, rerender } = render(getComponent({ events }));
+        const { container, rerender } = render(
+            getComponent({ events }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         let els = container.getElementsByClassName("mx_GenericEventListSummary");
         expect(els.length).toEqual(1);
         expect(els[0].getAttribute("data-testid")).toEqual("eventlistsummary-" + events[0].getId());
@@ -553,7 +571,10 @@ describe("MessagePanel", function () {
     it("prepends events into summaries during backward pagination without changing key", () => {
         const events = mkMelsEvents().slice(1, 11);
 
-        const { container, rerender } = render(getComponent({ events }));
+        const { container, rerender } = render(
+            getComponent({ events }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         let els = container.getElementsByClassName("mx_GenericEventListSummary");
         expect(els.length).toEqual(1);
         expect(els[0].getAttribute("data-testid")).toEqual("eventlistsummary-" + events[0].getId());
@@ -583,7 +604,10 @@ describe("MessagePanel", function () {
     it("assigns different keys to summaries that get split up", () => {
         const events = mkMelsEvents().slice(1, 11);
 
-        const { container, rerender } = render(getComponent({ events }));
+        const { container, rerender } = render(
+            getComponent({ events }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         let els = container.getElementsByClassName("mx_GenericEventListSummary");
         expect(els.length).toEqual(1);
         expect(els[0].getAttribute("data-testid")).toEqual(`eventlistsummary-${events[0].getId()}`);
@@ -616,7 +640,7 @@ describe("MessagePanel", function () {
     it("doesn't lookup showHiddenEventsInTimeline while rendering", () => {
         // We're only interested in the setting lookups that happen on every render,
         // rather than those happening on first mount, so let's get those out of the way
-        const { rerender } = render(getComponent({ events: [] }));
+        const { rerender } = render(getComponent({ events: [] }), clientAndSDKContextRenderOptions(client, sdkContext));
 
         // Set up our spy and re-render with new events
         const settingsSpy = jest.spyOn(SettingsStore, "getValue").mockClear();
@@ -654,7 +678,10 @@ describe("MessagePanel", function () {
                 ts: 3,
             }),
         ];
-        const { container } = render(getComponent({ events }, { showHiddenEvents: true }));
+        const { container } = render(
+            getComponent({ events }, { showHiddenEvents: true }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
 
         const els = container.getElementsByClassName("mx_GenericEventListSummary");
         expect(els.length).toEqual(1);
@@ -678,7 +705,10 @@ describe("MessagePanel", function () {
                 }),
             );
         }
-        const { asFragment } = render(getComponent({ events }, { showHiddenEvents: false }));
+        const { asFragment } = render(
+            getComponent({ events }, { showHiddenEvents: false }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         expect(asFragment()).toMatchSnapshot();
     });
 
@@ -699,7 +729,10 @@ describe("MessagePanel", function () {
                 }),
             );
         }
-        const { asFragment } = render(getComponent({ events }, { showHiddenEvents: false }));
+        const { asFragment } = render(
+            getComponent({ events }, { showHiddenEvents: false }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         expect(asFragment()).toMatchSnapshot();
     });
 
@@ -720,7 +753,10 @@ describe("MessagePanel", function () {
                 }),
             );
         }
-        const { asFragment } = render(getComponent({ events }, { showHiddenEvents: true }));
+        const { asFragment } = render(
+            getComponent({ events }, { showHiddenEvents: true }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
         const cpt = asFragment();
 
         // Ignore properties that change every time
@@ -751,7 +787,10 @@ describe("MessagePanel", function () {
                 content: { topic: "TOPIC" },
             }),
         ];
-        const { container } = render(getComponent({ events, showReadReceipts: true }));
+        const { container } = render(
+            getComponent({ events, showReadReceipts: true }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
 
         const tiles = container.getElementsByClassName("mx_EventTile");
         expect(tiles.length).toEqual(2);
@@ -784,7 +823,10 @@ describe("MessagePanel", function () {
             },
             true,
         );
-        const { container } = render(getComponent({ events, showReadReceipts: true }));
+        const { container } = render(
+            getComponent({ events, showReadReceipts: true }),
+            clientAndSDKContextRenderOptions(client, sdkContext),
+        );
 
         const tiles = container.getElementsByClassName("mx_EventTile");
         expect(tiles.length).toEqual(2);
