@@ -55,7 +55,6 @@ import { Action } from "../../../../src/dispatcher/actions";
 import defaultDispatcher from "../../../../src/dispatcher/dispatcher";
 import { type ViewRoomPayload } from "../../../../src/dispatcher/payloads/ViewRoomPayload";
 import { RoomView } from "../../../../src/components/structures/RoomView";
-import ResizeNotifier from "../../../../src/utils/ResizeNotifier";
 import SettingsStore from "../../../../src/settings/SettingsStore";
 import { SettingLevel } from "../../../../src/settings/SettingLevel";
 import DMRoomMap from "../../../../src/utils/DMRoomMap";
@@ -76,8 +75,11 @@ import MatrixClientContext from "../../../../src/contexts/MatrixClientContext";
 import { type ViewUserPayload } from "../../../../src/dispatcher/payloads/ViewUserPayload.ts";
 import { CallStore } from "../../../../src/stores/CallStore.ts";
 import MediaDeviceHandler, { MediaDeviceKindEnum } from "../../../../src/MediaDeviceHandler.ts";
-import Modal from "../../../../src/Modal.tsx";
+import Modal, { type ComponentProps } from "../../../../src/Modal.tsx";
 import ErrorDialog from "../../../../src/components/views/dialogs/ErrorDialog.tsx";
+import * as pinnedEventHooks from "../../../../src/hooks/usePinnedEvents";
+import { TimelineRenderingType } from "../../../../src/contexts/RoomContext";
+import { ModuleApi } from "../../../../src/modules/Api";
 
 // Used by group calls
 jest.spyOn(MediaDeviceHandler, "getDevices").mockResolvedValue({
@@ -90,7 +92,6 @@ describe("RoomView", () => {
     let cli: MockedObject<MatrixClient>;
     let room: Room;
     let rooms: Map<string, Room>;
-    let roomCount = 0;
     let stores: SdkContextClass;
     let crypto: CryptoApi;
 
@@ -101,7 +102,9 @@ describe("RoomView", () => {
         mockPlatformPeg({ reload: () => {} });
         cli = mocked(stubClient());
 
-        room = new Room(`!${roomCount++}:example.org`, cli, "@alice:example.org");
+        const roomName = (expect.getState().currentTestName ?? "").replace(/[^a-zA-Z0-9]/g, "").toLowerCase();
+
+        room = new Room(`!${roomName}:example.org`, cli, "@alice:example.org");
         jest.spyOn(room, "findPredecessor");
         room.getPendingEvents = () => [];
         rooms = new Map();
@@ -124,10 +127,18 @@ describe("RoomView", () => {
     afterEach(() => {
         unmockPlatformPeg();
         jest.clearAllMocks();
+
+        // Can't jest.restoreAllMocks() because some tests will break
+        jest.spyOn(pinnedEventHooks, "usePinnedEvents").mockRestore();
+        jest.spyOn(pinnedEventHooks, "useSortedFetchedPinnedEvents").mockRestore();
+
         cleanup();
     });
 
-    const mountRoomView = async (ref?: RefObject<RoomView | null>): Promise<RenderResult> => {
+    const mountRoomView = async (
+        ref?: RefObject<RoomView | null>,
+        props?: Partial<ComponentProps<typeof RoomView>>,
+    ): Promise<RenderResult> => {
         if (stores.roomViewStore.getRoomId() !== room.roomId) {
             const switchedRoom = new Promise<void>((resolve) => {
                 const subFn = () => {
@@ -151,18 +162,21 @@ describe("RoomView", () => {
         }
 
         const roomView = render(
-            <MatrixClientContext.Provider value={cli}>
-                <SDKContext.Provider value={stores}>
-                    <RoomView
-                        // threepidInvite should be optional on RoomView props
-                        // it is treated as optional in RoomView
-                        threepidInvite={undefined as any}
-                        resizeNotifier={new ResizeNotifier()}
-                        forceTimeline={false}
-                        ref={ref}
-                    />
-                </SDKContext.Provider>
-            </MatrixClientContext.Provider>,
+            <RoomView
+                // threepidInvite should be optional on RoomView props
+                // it is treated as optional in RoomView
+                threepidInvite={undefined as any}
+                forceTimeline={false}
+                ref={ref}
+                {...props}
+            />,
+            {
+                wrapper: ({ children }) => (
+                    <MatrixClientContext.Provider value={cli}>
+                        <SDKContext.Provider value={stores}>{children}</SDKContext.Provider>
+                    </MatrixClientContext.Provider>
+                ),
+            },
         );
         await flushPromises();
         return roomView;
@@ -196,7 +210,6 @@ describe("RoomView", () => {
                         // threepidInvite should be optional on RoomView props
                         // it is treated as optional in RoomView
                         threepidInvite={undefined}
-                        resizeNotifier={new ResizeNotifier()}
                         forceTimeline={false}
                         onRegistered={jest.fn()}
                     />
@@ -212,6 +225,26 @@ describe("RoomView", () => {
         return ref.current!;
     };
 
+    it("gets a room view store from MultiRoomViewStore when given a room ID", async () => {
+        stores.multiRoomViewStore.getRoomViewStoreForRoom = jest.fn().mockReturnValue(stores.roomViewStore);
+
+        const ref = createRef<RoomView>();
+        render(
+            <MatrixClientContext.Provider value={cli}>
+                <SDKContext.Provider value={stores}>
+                    <RoomView
+                        threepidInvite={undefined as any}
+                        forceTimeline={false}
+                        ref={ref}
+                        roomId="!room:example.dummy"
+                    />
+                </SDKContext.Provider>
+            </MatrixClientContext.Provider>,
+        );
+
+        expect(stores.multiRoomViewStore.getRoomViewStoreForRoom).toHaveBeenCalledWith("!room:example.dummy");
+    });
+
     it("should show member list right panel phase on Action.ViewUser without `payload.member`", async () => {
         const spy = jest.spyOn(stores.rightPanelStore, "showOrHidePhase");
         await renderRoomView(false);
@@ -232,6 +265,76 @@ describe("RoomView", () => {
         expect(instance.getHiddenHighlightCount()).toBe(0);
     });
 
+    it("should hide the composer when hideComposer=true", async () => {
+        // Join the room
+        jest.spyOn(room, "getMyMembership").mockReturnValue(KnownMembership.Join);
+        const { asFragment } = await mountRoomView(undefined, { hideComposer: true });
+
+        expect(screen.queryByRole("textbox", { name: "Send an unencrypted message…" })).not.toBeInTheDocument();
+        expect(asFragment()).toMatchSnapshot();
+    });
+
+    it("should hide the header when hideHeader=true", async () => {
+        // Join the room
+        jest.spyOn(room, "getMyMembership").mockReturnValue(KnownMembership.Join);
+        const { asFragment } = await mountRoomView(undefined, { hideHeader: true });
+
+        // Check that the room name button in the header is not rendered
+        expect(screen.queryByRole("button", { name: room.name })).not.toBeInTheDocument();
+        expect(asFragment()).toMatchSnapshot();
+    });
+
+    it("should hide the right panel when hideRightPanel=true", async () => {
+        // Join the room
+        jest.spyOn(room, "getMyMembership").mockReturnValue(KnownMembership.Join);
+        const { asFragment, rerender } = await mountRoomView(undefined);
+
+        defaultDispatcher.dispatch<ViewUserPayload>(
+            {
+                action: Action.ViewUser,
+                member: undefined,
+            },
+            true,
+        );
+
+        // Check that the right panel is rendered
+        await expect(screen.findByTestId("right-panel")).resolves.toBeTruthy();
+        // Now rerender with hideRightPanel=true
+        rerender(<RoomView threepidInvite={undefined} forceTimeline={false} hideRightPanel={true} />);
+        // Check that the right panel is not rendered
+        await expect(screen.findByTestId("right-panel")).rejects.toThrow();
+        expect(asFragment()).toMatchSnapshot();
+    });
+
+    it("should hide the pinned message banner when hidePinnedMessageBanner=true", async () => {
+        // Join the room
+        jest.spyOn(room, "getMyMembership").mockReturnValue(KnownMembership.Join);
+
+        const pinnedEvent = new MatrixEvent({
+            type: EventType.RoomMessage,
+            sender: "@alice:example.org",
+            content: {
+                body: "First pinned message",
+                msgtype: "m.text",
+            },
+            room_id: room.roomId,
+            origin_server_ts: 0,
+            event_id: "$eventId",
+        });
+
+        jest.spyOn(pinnedEventHooks, "usePinnedEvents").mockReturnValue([pinnedEvent.getId()!]);
+        jest.spyOn(pinnedEventHooks, "useSortedFetchedPinnedEvents").mockReturnValue([pinnedEvent]);
+
+        const { asFragment, rerender } = await mountRoomView(undefined);
+        // Check that the pinned message banner is rendered
+        await expect(screen.findByTestId("pinned-message-banner")).resolves.toBeTruthy();
+        // Now rerender with hidePinnedMessagesBanner=true
+        rerender(<RoomView threepidInvite={undefined} forceTimeline={false} hidePinnedMessageBanner={true} />);
+        // Check that the pinned message banner is not rendered
+        await expect(screen.findByTestId("pinned-message-banner")).rejects.toThrow();
+        expect(asFragment()).toMatchSnapshot();
+    });
+
     describe("invites", () => {
         beforeEach(() => {
             const member = new RoomMember(room.roomId, cli.getSafeUserId());
@@ -708,7 +811,7 @@ describe("RoomView", () => {
         });
 
         it("should switch rooms when edit is clicked on a search result for a different room", async () => {
-            const room2 = new Room(`!${roomCount++}:example.org`, cli, "@alice:example.org");
+            const room2 = new Room(`!roomswitchtest:example.org`, cli, "@alice:example.org");
             rooms.set(room2.roomId, room2);
 
             room.getMyMembership = jest.fn().mockReturnValue(KnownMembership.Join);
@@ -905,4 +1008,52 @@ describe("RoomView", () => {
             });
         });
     });
+
+    it("should not change room when editing event in a room displayed in module", async () => {
+        const room2 = new Room("!room2:example.org", cli, "@alice:example.org");
+        rooms.set(room2.roomId, room2);
+        room.getMyMembership = jest.fn().mockReturnValue(KnownMembership.Join);
+        room2.getMyMembership = jest.fn().mockReturnValue(KnownMembership.Join);
+
+        await mountRoomView();
+
+        // Mock the spaceStore activeSpace and ModuleApi setup
+        jest.spyOn(stores.spaceStore, "activeSpace", "get").mockReturnValue("space1");
+        // Mock that room2 is displayed in a module
+        ModuleApi.instance.extras.getVisibleRoomBySpaceKey("space1", () => [room2.roomId]);
+
+        // Mock the roomViewStore method
+        jest.spyOn(stores.roomViewStore, "isRoomDisplayedInModule").mockReturnValue(true);
+
+        // Create an event in room2 to edit
+        const eventInRoom2 = new MatrixEvent({
+            type: "m.room.message",
+            event_id: "$edit-event:example.org",
+            room_id: room2.roomId,
+            sender: "@alice:example.org",
+            content: {
+                body: "Original message",
+                msgtype: "m.text",
+            },
+        });
+
+        const dispatchSpy = jest.spyOn(defaultDispatcher, "dispatch");
+
+        // Dispatch EditEvent for event in room2 (which is displayed in module)
+        defaultDispatcher.dispatch({
+            action: Action.EditEvent,
+            event: eventInRoom2,
+            timelineRenderingType: TimelineRenderingType.Room,
+        });
+
+        await flushPromises();
+
+        // Should not dispatch ViewRoom action since room2 is displayed in module
+        expect(dispatchSpy).not.toHaveBeenCalledWith(
+            expect.objectContaining({
+                action: Action.ViewRoom,
+                room_id: room2.roomId,
+            }),
+        );
+    });
 });
