@@ -1,3 +1,10 @@
+/*
+Copyright 2025 Element Creations Ltd.
+
+SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only OR LicenseRef-Element-Commercial
+Please see LICENSE files in the repository root for full details.
+*/
+
 /* eslint-disable quote-props */
 
 const dotenv = require("dotenv");
@@ -214,6 +221,9 @@ module.exports = (env, argv) => {
 
                 // Define a variable so the i18n stuff can load
                 "$webapp": path.resolve(__dirname, "webapp"),
+
+                // Make shared-components imports resolve to EW counterpart
+                "counterpart": path.resolve(__dirname, "node_modules/counterpart"),
             },
             fallback: {
                 // Mock out the NodeFS module: The opus decoder imports this wrongly.
@@ -265,6 +275,10 @@ module.exports = (env, argv) => {
                         // our own source needs babel-ing
                         if (f.startsWith(path.resolve(__dirname, "src"))) return true;
 
+                        // We import the typescript source directly from shared-components
+                        // to avoid having to build as we dev, so include them too.
+                        if (f.startsWith(path.resolve(__dirname, "packages", "shared-components"))) return true;
+
                         // we use the original source files of js-sdk, so we need to
                         // run them through babel. Because the path tested is the resolved, absolute
                         // path, these could be anywhere thanks to yarn link. We must also not
